[llvm-commits] CVS: llvm/lib/Target/MachineFrameInfo.cpp TargetMachine.cpp

Misha Brukman brukman at neo.cs.uiuc.edu
Sun Oct 27 18:29:04 PST 2002


Changes in directory llvm/lib/Target:

MachineFrameInfo.cpp updated: 1.2 -> 1.3
TargetMachine.cpp updated: 1.12 -> 1.13

---
Log message:

Changed `MachineCodeForMethod' to `MachineFunction'.


---
Diffs of the changes:

Index: llvm/lib/Target/MachineFrameInfo.cpp
diff -u llvm/lib/Target/MachineFrameInfo.cpp:1.2 llvm/lib/Target/MachineFrameInfo.cpp:1.3
--- llvm/lib/Target/MachineFrameInfo.cpp:1.2	Fri Aug  9 15:08:03 2002
+++ llvm/lib/Target/MachineFrameInfo.cpp	Sun Oct 27 18:28:22 2002
@@ -7,10 +7,10 @@
 //===----------------------------------------------------------------------===//
 
 #include "llvm/Target/MachineFrameInfo.h"
-#include "llvm/CodeGen/MachineCodeForMethod.h"
+#include "llvm/CodeGen/MachineFunction.h"
 
 int
-MachineFrameInfo::getIncomingArgOffset(MachineCodeForMethod& mcInfo,
+MachineFrameInfo::getIncomingArgOffset(MachineFunction& mcInfo,
                                        unsigned argNum) const
 {
   assert(argsOnStackHaveFixedSize()); 
@@ -25,7 +25,7 @@
 
 
 int
-MachineFrameInfo::getOutgoingArgOffset(MachineCodeForMethod& mcInfo,
+MachineFrameInfo::getOutgoingArgOffset(MachineFunction& mcInfo,
                                        unsigned argNum) const
 {
   assert(argsOnStackHaveFixedSize()); 


Index: llvm/lib/Target/TargetMachine.cpp
diff -u llvm/lib/Target/TargetMachine.cpp:1.12 llvm/lib/Target/TargetMachine.cpp:1.13
--- llvm/lib/Target/TargetMachine.cpp:1.12	Sat Oct 12 19:34:10 2002
+++ llvm/lib/Target/TargetMachine.cpp	Sun Oct 27 18:28:22 2002
@@ -14,7 +14,7 @@
 #include "llvm/CodeGen/InstrScheduling.h"
 #include "llvm/CodeGen/RegisterAllocation.h"
 #include "llvm/CodeGen/PeepholeOpts.h"
-#include "llvm/CodeGen/MachineCodeForMethod.h"
+#include "llvm/CodeGen/MachineFunction.h"
 #include "llvm/CodeGen/MachineCodeForInstruction.h"
 #include "llvm/Reoptimizer/Mapping/MappingInfo.h" 
 #include "llvm/Reoptimizer/Mapping/FInfo.h" 
@@ -87,7 +87,7 @@
   }
 
   bool runOnFunction(Function &F) {
-    MachineCodeForMethod::construct(&F, Target);
+    MachineFunction::construct(&F, Target);
     return false;
   }
 };
@@ -117,7 +117,7 @@
 void
 TargetMachine::addPassesToEmitAssembly(PassManager &PM, std::ostream &Out)
 {
   // Construct and initialize the MachineCodeForMethod object for this fn.
   PM.add(new ConstructMachineCodeForFunction(*this));
 
   //Insert empty stackslots in the stack frame of each function
@@ -117,7 +117,7 @@
 TargetMachine::addPassesToEmitAssembly(PassManager &PM, std::ostream &Out)
 {
-  // Construct and initialize the MachineCodeForMethod object for this fn.
+  // Construct and initialize the MachineFunction object for this fn.
   PM.add(new ConstructMachineCodeForFunction(*this));
 





More information about the llvm-commits mailing list